==> Buke_autoTrade_Pypi-3.0.0-py3-none-any.whl: Buke_autoTrade_Pypi/generate_trval_data.py <==
from datetime import datetime, date
import numpy as np
import pandas as pd
from pandas import DataFrame
import math


def str_to_date(trading_day: str) -> date:
    return date(int(trading_day[:4]), int(trading_day[5:7]), int(trading_day[8:]))


def int_to_str(x: int) -> str:
    return "%06d" % x


# def read_trading_days(dir, end_date: date):
#
#     df = pd.read_csv(f"{dir}/data_file/korea_trading_days.csv", index_col=0)
#     df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
#     trading_days = df['날짜'].to_list()
#     trading_days = [day for day in trading_days if day <= end_date]
#
#     return trading_days


def read_day_price(dir, end_date: date):

    df = pd.read_csv(f"{dir}/data_file/수급데이터_2022_to_{end_date.year}.csv", index_col=0)
    df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
    # df['종목코드'] = df['종목코드'].apply(lambda x: int_to_str(x))
    return df


def read_index_day_price(dir):

    df = pd.read_csv(f"{dir}/data_file/MSCI_한국_ETF.csv", index_col=0)
    df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
    return df


# def read_index_history(dir, end_date: date):
#
#     ks_history = pd.read_csv(f"{dir}/data_file/코스피_종목리스트_2022_to_{end_date.year}.csv", index_col=0)
#     ks_history['날짜'] = ks_history['날짜'].apply(lambda day: str_to_date(day))
#     ks_history = ks_history.set_index('날짜')
#
#     kq_history = pd.read_csv(f"{dir}/data_file/코스닥_종목리스트_2022_to_{end_date.year}.csv")
#     kq_history['날짜'] = kq_history['날짜'].apply(lambda day: str_to_date(day))
#     kq_history = kq_history.set_index('날짜')
#     return ks_history, kq_history


def add_indicator(day_price: DataFrame, index_day_price: DataFrame) -> DataFrame:

    group_list = []
    기관_sum = {'날짜':[], '종가':[]}
    외인_sum = {'날짜':[], '종가':[]}

    grouped = day_price.groupby('날짜')
    for key, group in grouped:
        group = group.reset_index(drop=True)

        기관_ts_sum = sum(group['기관순거래대금'])
        기관_sum['날짜'].append(key)
        기관_sum['종가'].append(기관_ts_sum)

        외인_ts_sum = sum(group['외국인순거래대금'])
        외인_sum['날짜'].append(key)
        외인_sum['종가'].append(외인_ts_sum)

        group_list.append(group)

    기관_sum = pd.DataFrame(기관_sum)
    # print(기관_sum)
    기관_sum.to_csv(f"{dir}/data_file/기관순거래대금합.csv")

    외인_sum = pd.DataFrame(외인_sum)
    # print(외인_sum)
    외인_sum.to_csv(f"{dir}/data_file/외인순거래대금합.csv")

def generate_trval_data(dir, day):


    # # 1. 거래일 가져오기
    # trading_days_list = read_trading_days(dir, day)

    # 2. 일봉 가져오기
    day_price = read_day_price(dir, day)
    index_day_price = read_index_day_price(dir)

    # 3. 지수 종목 구성 내역 가져오기
    # kospi_history, kosdaq_history = read_index_history(dir, day)

    # 4. 매수 조건 및 우선순위 생성
    add_indicator(day_price, index_day_price)

==> Buke_autoTrade_Pypi-3.0.1-py3-none-any.whl: Buke_autoTrade_Pypi/generate_trval_data.py <==
from datetime import datetime, date
import numpy as np
import pandas as pd
from pandas import DataFrame
import math


def str_to_date(trading_day: str) -> date:
    return date(int(trading_day[:4]), int(trading_day[5:7]), int(trading_day[8:]))


def int_to_str(x: int) -> str:
    return "%06d" % x


# def read_trading_days(dir, end_date: date):
#
#     df = pd.read_csv(f"{dir}/data_file/korea_trading_days.csv", index_col=0)
#     df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
#     trading_days = df['날짜'].to_list()
#     trading_days = [day for day in trading_days if day <= end_date]
#
#     return trading_days


def read_day_price(dir, end_date: date):

    df = pd.read_csv(f"{dir}/data_file/수급데이터_2022_to_{end_date.year}.csv", index_col=0)
    df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
    # df['종목코드'] = df['종목코드'].apply(lambda x: int_to_str(x))
    return df


def read_index_day_price(dir):

    df = pd.read_csv(f"{dir}/data_file/MSCI_한국_ETF.csv", index_col=0)
    df['날짜'] = df['날짜'].apply(lambda day: str_to_date(day))
    return df


# def read_index_history(dir, end_date: date):
#
#     ks_history = pd.read_csv(f"{dir}/data_file/코스피_종목리스트_2022_to_{end_date.year}.csv", index_col=0)
#     ks_history['날짜'] = ks_history['날짜'].apply(lambda day: str_to_date(day))
#     ks_history = ks_history.set_index('날짜')
#
#     kq_history = pd.read_csv(f"{dir}/data_file/코스닥_종목리스트_2022_to_{end_date.year}.csv")
#     kq_history['날짜'] = kq_history['날짜'].apply(lambda day: str_to_date(day))
#     kq_history = kq_history.set_index('날짜')
#     return ks_history, kq_history


def add_indicator(dir, day_price: DataFrame, index_day_price: DataFrame) -> DataFrame:

    group_list = []
    기관_sum = {'날짜':[], '종가':[]}
    외인_sum = {'날짜':[], '종가':[]}

    grouped = day_price.groupby('날짜')
    for key, group in grouped:
        group = group.reset_index(drop=True)

        기관_ts_sum = sum(group['기관순거래대금'])
        기관_sum['날짜'].append(key)
        기관_sum['종가'].append(기관_ts_sum)

        외인_ts_sum = sum(group['외국인순거래대금'])
        외인_sum['날짜'].append(key)
        외인_sum['종가'].append(외인_ts_sum)

        group_list.append(group)

    기관_sum = pd.DataFrame(기관_sum)
    print(기관_sum)
    기관_sum.to_csv(f"{dir}/data_file/기관순거래대금합.csv")

    외인_sum = pd.DataFrame(외인_sum)
    print(외인_sum)
    외인_sum.to_csv(f"{dir}/data_file/외인순거래대금합.csv")

def generate_trval_data(dir, day):


    # # 1. 거래일 가져오기
    # trading_days_list = read_trading_days(dir, day)

    # 2. 일봉 가져오기
    day_price = read_day_price(dir, day)
    index_day_price = read_index_day_price(dir)

    # 3. 지수 종목 구성 내역 가져오기
    # kospi_history, kosdaq_history = read_index_history(dir, day)

    # 4. 매수 조건 및 우선순위 생성
    add_indicator(dir, day_price, index_day_price)
